huey, a little task queue — huey 0.4.0 documentation

### Navigation

- index
- next |
- huey 0.4.0 documentation »

# huey, a little task queue

a lightweight alternative.

- written in python
- no deps outside stdlib, except redis (or roll your own backend)
- support for django

named after my cat

Contents:

- Installing
  - Using git
- Upgrading
  - Invoker became Huey
  - Decorators are methods on Huey
  - No more `BaseConfiguration`
  - Simplified Django Settings
- Getting Started
  - General guide
  - Preventing tasks from executing
- Consuming Tasks
  - Options for the consumer
  - Consumer Internals
- Understanding how tasks are imported
  - Suggested organization of code
- Troubleshooting and Common Pitfalls
- Using Huey with Django
  - Huey Settings
  - Running the Consumer
  - Task API
- Huey’s API
  - Function decorators and helpers
  - AsyncData
  - Queues and DataStores

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- huey 0.4.0 documentation »